/************************************************************************
 *   IRC - Internet Relay Chat, m_extra/m_extra.c
 *   This file is copyright (C) 2001 Andrew Suffield
 *                                    <asuffield@users.sourceforge.net>
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 */

#include "config.h"
#include "msg.h"
#include "modules.h"
#include "parse.h"
#include "extra.h"
#include "hooks.h"

#include <string.h>

MODULE("extra")

static struct module_handle *mh;
static char desc[] = "Assorted extra stuff";
static char extra_version[] = RELEASE;

mod_deinit_func extra_deinit;

#ifdef STATIC_MODULES
struct module_handle *
extra_init(void)
#else
struct module_handle *
_modinit(void)
#endif
{
  struct Message *msg;

  if (is_silenced != NULL)
    return NULL;
  if (check_temp_invites != NULL)
    return NULL;

  if (!(mh = register_module(_name, desc, extra_version, &extra_deinit)))
    return NULL;

  mod_add_cmd(&away_msgtab, mh);
  mod_add_cmd(&tsdelta_msgtab, mh);
  mod_add_cmd(&utime_msgtab, mh);
  mod_add_cmd(&silence_msgtab, mh);
  for (msg = services_msgtab; msg->cmd; msg++)
    mod_add_cmd(msg, mh);

  /* Grab the hook for silences */
  is_silenced = _is_silenced;
  /* ...and temp invites */
  check_temp_invites = _check_temp_invites;

  return mh;
}

void
extra_deinit(int type)
{
  is_silenced = NULL;
  check_temp_invites = NULL;
}
